from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TarotSpreadRequest(_message.Message):
    __slots__ = ["question", "category", "spread_profile_id", "language"]
    QUESTION_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_FIELD_NUMBER: _ClassVar[int]
    SPREAD_PROFILE_ID_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    question: str
    category: str
    spread_profile_id: str
    language: str
    def __init__(self, question: _Optional[str] = ..., category: _Optional[str] = ..., spread_profile_id: _Optional[str] = ..., language: _Optional[str] = ...) -> None: ...

class TarotSpreadResponse(_message.Message):
    __slots__ = ["question", "category", "spread"]
    QUESTION_FIELD_NUMBER: _ClassVar[int]
    CATEGORY_FIELD_NUMBER: _ClassVar[int]
    SPREAD_FIELD_NUMBER: _ClassVar[int]
    question: str
    category: str
    spread: str
    def __init__(self, question: _Optional[str] = ..., category: _Optional[str] = ..., spread: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/tarot/spread.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18tarot/tarot/spread.proto\x12\x05tarot\"w\n\x12TarotSpreadRequest\x12\x10\n\x08question\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x19\n\x11spread_profile_id\x18\x03 \x01(\t\x12\x15\n\x08language\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_language\"I\n\x13TarotSpreadResponse\x12\x10\n\x08question\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x0e\n\x06spread\x18\x03 \x01(\t2\\\n\x0bTarotReader\x12M\n\x12RequestTarotSpread\x12\x19.tarot.TarotSpreadRequest\x1a\x1a.tarot.TarotSpreadResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.tarot.spread_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TAROTSPREADREQUEST']._serialized_start=35
  _globals['_TAROTSPREADREQUEST']._serialized_end=154
  _globals['_TAROTSPREADRESPONSE']._serialized_start=156
  _globals['_TAROTSPREADRESPONSE']._serialized_end=229
  _globals['_TAROTREADER']._serialized_start=231
  _globals['_TAROTREADER']._serialized_end=323
# @@protoc_insertion_point(module_scope)
